@@ -1,6 +1,6 @@
 /*  main.c -- main bcftools command front-end.
 
-    Copyright (C) 2012-2015 Genome Research Ltd.
+    Copyright (C) 2012-2018 Genome Research Ltd.
 
     Author: Petr Danecek <pd3@sanger.ac.uk>
 
@@ -22,6 +22,7 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.  */
 
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -54,6 +55,9 @@ int main_polysomy(int argc, char *argv[]);
 #endif
 int main_plugin(int argc, char *argv[]);
 int main_consensus(int argc, char *argv[]);
+int main_csq(int argc, char *argv[]);
+int bam_mpileup(int argc, char *argv[]);
+int main_sort(int argc, char *argv[]);
 
 typedef struct
 {
@@ -108,7 +112,12 @@ static cmd_t cmds[] =
     },
     { .func  = main_plugin,
       .alias = "plugin",
+#ifdef ENABLE_BCF_PLUGINS
       .help  = "user-defined plugins"
+#else
+      /* Do not advertise when plugins disabled. */
+      .help  = "-user-defined plugins"
+#endif
     },
     { .func  = main_vcfquery,
       .alias = "query",
@@ -118,6 +127,10 @@ static cmd_t cmds[] =
       .alias = "reheader",
       .help  = "modify VCF/BCF header, change sample names"
     },
+    { .func  = main_sort,
+      .alias = "sort",
+      .help  = "sort VCF/BCF file"
+    },
     { .func  = main_vcfview,
       .alias = "view",
       .help  = "VCF/BCF conversion, view, subset and filter VCF/BCF files"
@@ -138,7 +151,11 @@ static cmd_t cmds[] =
     },
     { .func  = main_vcfcnv,
       .alias = "cnv",
-      .help  = "-HMM CNV calling"    // do not advertise yet
+      .help  = "HMM CNV calling"
+    },
+    { .func  = main_csq,
+      .alias = "csq",
+      .help  = "call variation consequences"
     },
     { .func  = main_vcffilter,
       .alias = "filter",
@@ -148,10 +165,14 @@ static cmd_t cmds[] =
       .alias = "gtcheck",
       .help  = "check sample concordance, detect sample swaps and contamination"
     },
+    { .func  = bam_mpileup,
+        .alias = "mpileup",
+        .help  = "multi-way pileup producing genotype likelihoods"
+    },
 #if USE_GPL
     { .func  = main_polysomy,
       .alias = "polysomy",
-      .help  = "-detect number of chromosomal copies",
+      .help  = "detect number of chromosomal copies",
     },
 #endif
     { .func  = main_vcfroh,
@@ -188,7 +209,7 @@ static void usage(FILE *fp)
 #endif
     fprintf(fp, "Version: %s (using htslib %s)\n", bcftools_version(), hts_version());
     fprintf(fp, "\n");
-    fprintf(fp, "Usage:   bcftools <command> <argument>\n");
+    fprintf(fp, "Usage:   bcftools [--version|--version-only] [--help] <command> <argument>\n");
     fprintf(fp, "\n");
     fprintf(fp, "Commands:\n");
 
@@ -219,7 +240,7 @@ int main(int argc, char *argv[])
     if (argc < 2) { usage(stderr); return 1; }
 
     if (strcmp(argv[1], "version") == 0 || strcmp(argv[1], "--version") == 0 || strcmp(argv[1], "-v") == 0) {
-        printf("bcftools %s\nUsing htslib %s\nCopyright (C) 2015 Genome Research Ltd.\n", bcftools_version(), hts_version());
+        printf("bcftools %s\nUsing htslib %s\nCopyright (C) 2018 Genome Research Ltd.\n", bcftools_version(), hts_version());
 #if USE_GPL
         printf("License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n");
 #else
